@@ -21,11 +21,6 @@ def main(cfg):
     )
     deploy.mkdir(exist_ok=True, parents=True)
 
-    src = TEMPLATES_PATH / "cleanlogs.ps1"
-    dst = deploy / src.name
-    log.debug(f"cwd: {pathlib.Path.cwd()}")
-    shutil.copy(src, dst)
-
     src = TEMPLATES_PATH / "product1.wxs"
     tpl_str = src.read_text()
     tpl = jinja2.Template(tpl_str)
@@ -64,25 +59,17 @@ def main(cfg):
     dst.unlink(missing_ok=True)
     shutil.copy(src, dst)
 
-    path = TEMPLATES_PATH / "encassist.ini"
-    tpl_str = path.read_text()
-    tpl = jinja2.Template(tpl_str)
-    rendered = tpl.render(data=cfg)
-    out_path = deploy / path.name
-    out_path.parent.mkdir(parents=True, exist_ok=True)
-    log.debug(f"creating {out_path}")
-    out_path.write_text(rendered)
-
-    path = TEMPLATES_PATH / "service.ps1"
-    tpl_str = path.read_text()
-    tpl = jinja2.Template(tpl_str)
-    rendered = tpl.render(data=cfg)
-    out_path = deploy / path.name
-    out_path.parent.mkdir(parents=True, exist_ok=True)
-    out_path.write_text(rendered)
-
     src = bin_path / "IRIS Decoder Placard.png"
     shutil.copy(src, work1 / src.name)
 
     pdf = bin_path / "streambox_iris_quickstart.pdf"
     shutil.copy(pdf, work1 / pdf.name)
+
+    ini = bin_path / "encassist.ini"
+    shutil.copy(ini, deploy / ini.name)
+
+    ps = bin_path / "service.ps1"
+    shutil.copy(ps, deploy / ps.name)
+
+    ps = bin_path / "cleanlogs.ps1"
+    shutil.copy(ps, deploy / ps.name)
